<template>
  <a-modal
    :confirm-loading='confirmLoading1'
    :visible='visible1'
    :width='1000'
    title='选择地址'
    @cancel='handleCancel'
    @ok='handleOk'
  >
    <a-spin :spinning='load'>
      <a-card :bordered='false'>
        <div>
          <a-table
            ref='table'
            :columns='columns'
            :customRow='clickThenSelect'
            :dataSource='dataSource'
            :loading='loading'
            :pagination='ipagination'
            :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
            bordered
            class='j-table-force-nowrap'
            rowKey='id'
            size='small'
            @change='handleTableChange'
          >
          </a-table>
        </div>
      </a-card>
    </a-spin>

  </a-modal>
</template>

<script>
import ParameterGroupModel from './SolidParameterModel'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import { getAction } from '@/api/manage'

export default {
  name: 'ParameterAddress',
  mixins: [JeecgListMixin],
  components: {
    ParameterGroupModel,
    JDictSelectTag,
    JInput,
    JEllipsis
  },
  data() {
    return {
      visible1: false,
      confirmLoading1: false,
      confirmLoading: false,
      visible: false,
      disableSubmit: true,
      columns: [
        {
          title: '序号',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '参数名称',
          align: 'center',
          dataIndex: 'name'
        },
        {
          title: '描述',
          align: 'center',
          dataIndex: 'describe'
        },
        {
          title: '参数类型',
          align: 'center',
          dataIndex: 'dataType'
        }
      ],
      load: false,
      url: {
        list: '/equipment/queryParameter'
      }
    }
  },
  props: ['serverId', 'tree'],
  watch: {
    serverId: {
      handler() {
        this.loadData()
      }
    }
  },
  methods: {
    // 查询终端列表
    loadData() {
      getAction(this.url.list, { id: this.serverId }).then((res) => {
        if (res.success) {
          this.dataSource = res.result
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })

    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onSelectChange(selectedRowKeys) {
      this.selectedRowKeys = selectedRowKeys
    },
    modalFormOk(val) {
      // 调用父组件方法
      this.$emit('tree')
      // 新增/修改 成功时，重载列表
      this.loadData()
      this.selectedRowKeys = [val.id]
    },
    searchQuery() {
      this.loadData()
      this.onClearSelected()
    },
    searchReset() {
      this.queryParam = {}
      this.loadData()
      this.onClearSelected()
    },
    handleCancel() {
      this.visible1 = false
    },
    handleOk() {
      const that = this
      // 保存数据
      this.selectionRows = this.dataSource.filter((item) => this.selectedRowKeys[0] == item.id)
      that.$emit('ok', this.selectionRows[0])
      this.visible1 = false
    }
  }
}
</script>
<style>
</style>
